<?php

/**
 * @file
 * Contains the SpinHelper class.
 *
 * General private and helper methods. If it's not a hook, SQL or cacheable data
 * for pages/blocks then it probably goes here.
 */

/**
 * Helper class.
 */
class SpinHelper {
  const AUTOPLAY = 'false';
  const HEIGHT = '100%';
  const SELECTORS = 'bottom';
  const SELECTORS_SIZE = '50';
  const SELECTORS_STYLE = 'thumbnails';

  /**
   * Retrive the image URL.
   *
   * @param int $fid
   *   The file ID.
   * @param array $element
   *   An element array.
   * @param string $style
   *   The image style.
   *
   * @return string
   *   A themed preview image.
   */
  public static function getPreview($fid, array &$element = array(), $style = 'thumbnail') {
    $file = file_load($fid);

    if (isset($element['#value']['width']) && isset($element['#value']['height'])) {
      $info = array(
        'width'  => $element['#value']['width'],
        'height' => $element['#value']['height'],
      );
    }
    elseif (!empty($file->uri)) {
      $info = image_get_info($file->uri);
    }
    $img = array(
      'style_name' => $style,
      'path'       => !empty($file->uri) ? $file->uri : '',
      'width'      => !empty($info['width']) ? $info['width'] : '',
      'height'     => !empty($info['height']) ? $info['height'] : '',
    );
    $element['width'] = array(
      '#type'  => 'hidden',
      '#value' => $img['width'],
    );
    $element['height'] = array(
      '#type'  => 'hidden',
      '#value' => $img['height'],
    );
    return !empty($file->uri) ? theme('image_style', $img) : '';
  }

  /**
   * Build a string of data-options.
   *
   * @return string
   *   A string of Magic Slideshow data options.
   */
  public static function getSlideshowDataOptions() {
    $defaults = array(
      'autoplay'        => self::AUTOPLAY,
      'height'          => self::HEIGHT,
      'selectors'       => self::SELECTORS,
      'selectors-size'  => self::SELECTORS_SIZE,
      'selectors-style' => self::SELECTORS_STYLE,
    );
    $option_string = '';

    $data_options = variable_get('spin_slideshow_data_options', array()) + $defaults;

    ksort($data_options);

    foreach ($data_options as $key => $val) {
      $option_string .= $option_string ? "; $key:$val" : "$key:$val";
    }
    return $option_string;
  }

  /**
   * Build a string of data-options.
   *
   * @return string
   *   A string of Magic Slideshow data options.
   */
  public static function getSpinQueryString() {
    $defaults = array();
    $option_string = '';

    $data_options = variable_get('spin_spin_data_options', array()) + $defaults;

    ksort($data_options);

    foreach ($data_options as $key => $val) {
      $option_string .= $option_string ? "&$key=$val" : "?$key=$val";
    }
    return $option_string;
  }

  /**
   * Retrive the image URL.
   *
   * @param int $fid
   *   The file ID.
   * @param string $style
   *   The image style.
   *
   * @return string
   *   The URL to the image.
   */
  public static function getThumb($fid, $style) {
    $file = file_load($fid);

    if (!$file->status) {
      $file->status = FILE_STATUS_PERMANENT;
      file_save($file);

      if (arg(0) == 'node' && is_numeric(arg(1))) {
        file_usage_add($file, 'spin', 'node', arg(1));
      }
      $file = file_load($fid);
    }
    $style_uri = !empty($file->uri) ? image_style_path($style, $file->uri) : '';

    if (!$style_uri) {
      return '';
    }
    if (!file_exists($style_uri)) {
      image_style_create_derivative(image_style_load($style), $file->uri, $style_uri);
    }
    return file_exists($style_uri) ? image_style_url($style, $file->uri) : file_create_url($file->uri);
  }

  /**
   * Scan theme and module directories for the templates.
   *
   * @param string $module
   *   The module name, (without the suffix).
   * @param string $template
   *   The template name, (without the suffixes).
   *
   * @return string
   *   Drupal path to the template's directory, (default .../module/templates).
   */
  public static function tplPath($module, $template = '') {
    $theme_path = drupal_get_path('theme', variable_get('theme_default', 'garland'));

    $scan = file_scan_directory($theme_path, "/^$template\.tpl\.php$/", array('recurse' => TRUE, 'filename' => TRUE));

    if (!count($scan)) {
      $scan = file_scan_directory(drupal_get_path('module', $module), "/^$template\.tpl\.php$/", array('recurse' => TRUE, 'filename' => TRUE));
    }
    return count($scan) ? preg_replace('/(\/[^\/]+)$/', '', key($scan)) : drupal_get_path('module', $module) . '/templates';
  }

}
